@@ -1,6 +1,7 @@
 import asyncio
 from typing import Awaitable, Callable
 
+from .task_group import TaskGroup
 from ..config import Config
 from ..typing import ASGIFramework
 from ..utils import invoke_asgi
@@ -20,12 +21,12 @@ async def _handle(
 
 
 async def spawn_app(
+    task_group: TaskGroup,
     app: ASGIFramework,
-    loop: asyncio.AbstractEventLoop,
     config: Config,
     scope: dict,
     send: Callable[[dict], Awaitable[None]],
 ) -> Callable[[dict], Awaitable[None]]:
     app_queue: asyncio.Queue = asyncio.Queue(config.max_app_queue_size)
-    loop.create_task(_handle(app, config, scope, app_queue.get, send))
+    task_group.spawn(_handle(app, config, scope, app_queue.get, send))
     return app_queue.put
