@@ -8,7 +8,7 @@ import stat
 import types
 import warnings
 from dataclasses import dataclass
-from ssl import SSLContext, VerifyFlags, VerifyMode  # type: ignore
+from ssl import SSLContext, VerifyFlags, VerifyMode
 from time import time
 from typing import Any, AnyStr, Dict, List, Mapping, Optional, Tuple, Type, Union
 from wsgiref.handlers import format_date_time
@@ -225,10 +225,13 @@ class Config:
 
         for alt_svc_header in self.alt_svc_headers:
             headers.append((b"alt-svc", alt_svc_header.encode()))
-        if len(self.alt_svc_headers) == 0:
-            for bind in self._quic_bind:
-                port = int(bind.split(":")[-1])
-                headers.append((b"alt-svc", b'h3-23=":%d"; ma=3600' % port))
+        if len(self.alt_svc_headers) == 0 and self._quic_bind:
+            from aioquic.h3.connection import H3_ALPN
+
+            for version in H3_ALPN:
+                for bind in self._quic_bind:
+                    port = int(bind.split(":")[-1])
+                    headers.append((b"alt-svc", b'%s=":%d"; ma=3600' % (version.encode(), port)))
 
         return headers
 
