@@ -18,7 +18,7 @@ class EventWrapper:
         self._event = trio.Event()
 
     async def clear(self) -> None:
-        self._event.clear()
+        self._event = trio.Event()
 
     async def wait(self) -> None:
         await self._event.wait()
@@ -33,6 +33,7 @@ class TCPServer:
         self.config = config
         self.protocol: ProtocolWrapper
         self.send_lock = trio.Lock()
+        self.timeout_lock = trio.Lock()
         self.stream = stream
 
         self._keep_alive_timeout_handle: Optional[trio.CancelScope] = None
@@ -125,13 +126,18 @@ class TCPServer:
         await self.stream.aclose()
 
     async def _update_keep_alive_timeout(self) -> None:
-        if self._keep_alive_timeout_handle is not None:
-            self._keep_alive_timeout_handle.cancel()
-        self._keep_alive_timeout_handle = None
-        if self.protocol.idle:
-            self._keep_alive_timeout_handle = await self.nursery.start(
-                _call_later, self.config.keep_alive_timeout, self.stream.aclose
-            )
+        async with self.timeout_lock:
+            if self._keep_alive_timeout_handle is not None:
+                self._keep_alive_timeout_handle.cancel()
+            self._keep_alive_timeout_handle = None
+            if self.protocol.idle:
+                self._keep_alive_timeout_handle = await self.nursery.start(
+                    _call_later, self.config.keep_alive_timeout, self._timeout
+                )
+
+    async def _timeout(self) -> None:
+        await self.protocol.handle(Closed())
+        await self.stream.aclose()
 
 
 async def _call_later(
